from django.core.management.base import BaseCommand
from wagtail.models import Site, Page
from core.models.frontend import LandingPage
from core.models.project import ProjectIndexPage


class Command(BaseCommand):
    help = 'Set up initial page structure'

    def handle(self, *args, **options):
        if LandingPage.objects.first():
            return

        # remove default root page
        # so we can reuse 'home' slug
        default_site = Site.objects.first()
        default_site.root_page.delete()

        # create new root landing page
        root = Page.get_first_root_node()
        home = LandingPage(
            title='Home',
            slug='home',
        )
        root.add_child(instance=home)
        default_site.root_page = home
        default_site.save()

        # create projects index
        projects = ProjectIndexPage(
            title='Projects',
            slug='projects',
        )
        home.add_child(instance=projects)
