from django.db import models
from wagtail.admin.panels import FieldPanel, InlinePanel
from wagtail.images.models import Image
from wagtail.models import Page, ParentalKey


class LandingPage(Page):
    content_panels = Page.content_panels + [
        InlinePanel('carousel_images', label='Carousel images'),
        InlinePanel('featured_pages', label='Featured pages'),
    ]


class LandingPageImage(models.Model):
    owner = ParentalKey(
        LandingPage,
        on_delete=models.CASCADE,
        related_name='carousel_images',
    )
    image = models.ForeignKey(Image, on_delete=models.SET_NULL, null=True)
    caption = models.CharField(max_length=255)

    panels = [
        FieldPanel('image'),
        FieldPanel('caption'),
    ]

    def __str__(self):
        return self.caption


class LandingPageFeature(models.Model):
    owner = ParentalKey(
        LandingPage,
        on_delete=models.CASCADE,
        related_name='featured_pages',
    )
    page = models.ForeignKey(Page, on_delete=models.SET_NULL, null=True)
    image = models.ForeignKey(Image, on_delete=models.SET_NULL, null=True)
    caption = models.CharField(max_length=255)

    panels = [
        FieldPanel('page'),
        FieldPanel('image'),
        FieldPanel('caption'),
    ]

    def __str__(self):
        return self.page.title

