from django.db import models
from wagtail.search import index
from .util import Named, LegacyModel


STATES = [
    ('AL', 'Alabama'),
    ('AK', 'Alaska'),
    ('AZ', 'Arizona'),
    ('AR', 'Arkansas'),
    ('CA', 'California'),
    ('CO', 'Colorado'),
    ('CT', 'Connecticut'),
    ('DE', 'Delaware'),
    ('FL', 'Florida'),
    ('GA', 'Georgia'),
    ('HI', 'Hawaii'),
    ('ID', 'Idaho'),
    ('IL', 'Illinois'),
    ('IN', 'Indiana'),
    ('IA', 'Iowa'),
    ('KS', 'Kansas'),
    ('KY', 'Kentucky'),
    ('LA', 'Louisiana'),
    ('MA', 'Massachusetts'),
    ('MD', 'Maryland'),
    ('ME', 'Maine'),
    ('MI', 'Michigan'),
    ('MN', 'Minnesota'),
    ('MS', 'Mississippi'),
    ('MO', 'Missouri'),
    ('MT', 'Montana'),
    ('NE', 'Nebraska'),
    ('NV', 'Nevada'),
    ('NH', 'New Hampshire'),
    ('NJ', 'New Jersey'),
    ('NM', 'New Mexico'),
    ('NY', 'New York'),
    ('NC', 'North Carolina'),
    ('ND', 'North Dakota'),
    ('OH', 'Ohio'),
    ('OK', 'Oklahoma'),
    ('OR', 'Oregon'),
    ('PA', 'Pennsylvania'),
    ('RI', 'Rhode Island'),
    ('SC', 'South Carolina'),
    ('SD', 'South Dakota'),
    ('TN', 'Tennessee'),
    ('TX', 'Texas'),
    ('UT', 'Utah'),
    ('VT', 'Vermont'),
    ('VA', 'Virginia'),
    ('WA', 'Washington'),
    ('WV', 'West Virginia'),
    ('WI', 'Wisconsin'),
    ('WY', 'Wyoming'),
]


class Location(index.Indexed, Named, LegacyModel):
    street = models.CharField(max_length=255, blank=True, null=True)
    city = models.CharField(max_length=255, blank=True, null=True)
    province = models.CharField(max_length=2, choices=STATES, verbose_name='state')
    postal_code = models.CharField(max_length=255, blank=True, null=True)
    notes = models.TextField(blank=True, null=True)

    search_fields = [
        index.SearchField('name'),
        index.AutocompleteField('name'),

        index.SearchField('street'),
        index.AutocompleteField('street'),

        index.SearchField('city'),
        index.AutocompleteField('city'),
        index.FilterField('city'),

        index.SearchField('province'),
        index.AutocompleteField('province'),
        index.FilterField('province'),

        index.FilterField('postal_code'),
        index.AutocompleteField('postal_code'),
    ]

    def __str__(self):
        return '%s %s %s, %s  %s' % (
            self.name,
            self.street,
            self.city,
            self.province,
            self.postal_code,
        )

    def as_p(self):
        return f'''
        <p>
        {self.street}<br />
        {self.city}, {self.province}<br />
        {self.postal_code}
        </p>
        '''

    def without_name(self):
        return '%s %s %s %s' % (
            self.street,
            self.city,
            self.province,
            self.postal_code,
        )

    def maps_query(self):
        return f'https://google.com/maps/search/?q={self.without_name()}'

    class Meta:
        ordering = ['province', 'city', 'street']
        unique_together = [
            ['street', 'city', 'province'],
        ]
