from django.db import models


class Named(models.Model):
    name = models.CharField(max_length=255)

    def __str__(self):
        return self.name

    class Meta:
        abstract = True
        ordering = ['name']


class Orderable(models.Model):
    sort_order = models.IntegerField(
        default=0,
        help_text='Lower numbers sort earlier',
    )

    class Meta:
        abstract = True
        ordering = ['sort_order']


class ChoiceList(Named, Orderable):
    class Meta:
        abstract = True
        ordering = ['sort_order', 'name']


class LegacyModel(models.Model):
    legacy_id = models.IntegerField(blank=True, null=True)

    class Meta:
        abstract = True


def cash_field(**kwargs):
    return models.DecimalField(decimal_places=2, max_digits=16, **kwargs)
