from wagtail.admin.panels import (
    Panel,
    HelpPanel,
    ObjectList,
    InlinePanel,
    FieldPanel,
)
from django.utils.functional import cached_property


class TemplatePanel(Panel):
    def __init__(self, template, **kwargs):
        super().__init__(**kwargs)
        self.template = template

    def clone_kwargs(self):
        kwargs = super().clone_kwargs()
        kwargs['template'] = self.template
        return kwargs

    class BoundPanel(Panel.BoundPanel):
        def __init__(self, **kwargs):
            super().__init__(**kwargs)
            self.template_name = self.panel.template


class CurrentRevision(ObjectList):
    class BoundPanel(ObjectList.BoundPanel):
        def __init__(self, **kwargs):
            super().__init__(**kwargs)
            self.heading = f'Current Revision ({self.instance.current_revision})'


class ReadOnlyInlinePanel(InlinePanel):
    def _make_children_readonly(children):
        panels = []
        for child in children:
            kwargs = child.clone_kwargs()
            if 'read_only' in kwargs:
                kwargs['read_only'] = True
            if 'children' in kwargs:
                kwargs['children'] = ReadOnlyInlinePanel._make_children_readonly(kwargs['children'])
            panels.append(child.__class__(**kwargs))
        return panels

    @cached_property
    def panel_definitions(self):
        return ReadOnlyInlinePanel._make_children_readonly(super().panel_definitions)

    class BoundPanel(InlinePanel.BoundPanel):
        template_name = 'wagtailadmin/panels/readonly_inline_panel.html'

        def get_context_data(self, parent_context=None):
            context = super().get_context_data(parent_context)
            context['hide_order'] = True
            context['hide_delete'] = True
            return context
