from django.urls import path, reverse
from wagtail import hooks
from wagtail.admin.menu import AdminOnlyMenuItem
from wagtail.admin.userbar import AccessibilityItem
from wagtail.snippets.models import register_snippet
from wagtail.snippets.wagtail_hooks import SnippetsMenuItem
from wagtail.snippets.action_menu import ActionMenuItem
from .models.bid import Bid
from .models.frontend import LandingPageFeature, LandingPageImage
from .views import (
    ProjectViewSetGroup,
    ProductViewSetGroup,
    BidViewSetGroup,
    edit_takeoff,
)


register_snippet(LandingPageFeature)
register_snippet(LandingPageImage)
register_snippet(ProjectViewSetGroup)
register_snippet(ProductViewSetGroup)
register_snippet(BidViewSetGroup)


@hooks.register('construct_wagtail_userbar')
def hide_accessibility(request, items):
    items[:] = [i for i in items if not isinstance(i, AccessibilityItem)]


@hooks.register('register_icons')
def register_icons(icons):
    return icons + [
        'core/building.svg',
        'core/location.svg',
        'core/helmet.svg',
    ]


@hooks.register('construct_main_menu')
def remove_snippets(request, menu_items):
    menu_items[:] = [item for item in menu_items if not isinstance(item, SnippetsMenuItem)]


@hooks.register('register_admin_urls')
def register_edit_takeoff():
    return [
        path(
            'snippets/core/scope/edit/<int:pk>/edit-takeoff',
            edit_takeoff,
            name='edit_takeoff',
        ),
    ]


class BidRevActionMenuItem(ActionMenuItem):
    def is_shown(self, context):
        return context['model'] == Bid


class CreateBidRevMenuItem(BidRevActionMenuItem):
    label = 'Create New Revision'
    name = 'create-bid-rev'
    icon_name = 'download'


@hooks.register('register_snippet_action_menu_item')
def register_finalize_bid_rev(whatisthisforthedocsdontmentionit):
    return CreateBidRevMenuItem()


class DeleteLastBidRevMenuItem(BidRevActionMenuItem):
    label = 'Delete Last Revision'
    name = 'delete-last-bid-rev'
    icon_name = 'cross'

    def is_shown(self, context):
        if 'instance' in context:
            bid = context['instance']
            return super().is_shown(context) and bid.revisions.count() > 0


@hooks.register('register_snippet_action_menu_item')
def register_delete_last_bid_rev(whatisthisforthedocsdontmentionit):
    return DeleteLastBidRevMenuItem()
