from django import forms
from django.contrib.auth.forms import ReadOnlyPasswordHashField
from django.core.exceptions import ValidationError

from .models import User


class UserCreationForm(forms.ModelForm):
    password1 = forms.CharField(
        label="Password",
        widget=forms.PasswordInput,
    )
    password2 = forms.CharField(
        label="Password confirmation",
        widget=forms.PasswordInput,
    )

    class Meta:
        model = User
        fields = ["email", 'first_name', 'last_name', 'groups']
        widgets = {"groups": forms.CheckboxSelectMultiple}

    def clean_password2(self):
        # Check that the two password entries match
        password1 = self.cleaned_data.get("password1")
        password2 = self.cleaned_data.get("password2")
        if password1 and password2 and password1 != password2:
            raise ValidationError("Passwords don't match")
        return password2

    def save(self, commit=True):
        # Save the provided password in hashed format
        user = super().save(commit=False)
        user.set_password(self.cleaned_data["password1"])
        if commit:
            user.save()
        return user


class UserChangeForm(forms.ModelForm):
    password = ReadOnlyPasswordHashField()

    def __init__(self, *args, **kwargs):
        kwargs.pop("editing_self", False)
        super().__init__(*args, **kwargs)

    class Meta:
        model = User
        fields = [
            "email",
            'first_name',
            'last_name',
            'is_active',
            'is_admin',
            'is_superuser',
            'groups',
        ]
        widgets = {"groups": forms.CheckboxSelectMultiple}
